%define major 14
%define libname %mklibname nghttp2_ %{major}
%define develname %mklibname -d nghttp2

%define with_docs 0

Summary: Experimental HTTP/2 client, server and proxy
Name: nghttp2
Version: 1.64.0
Release: %mkrel 1
License: MIT
Group: System/Libraries
URL: https://nghttp2.org/
Source0: https://github.com/tatsuhiro-t/nghttp2/releases/download/v%{version}/nghttp2-%{version}.tar.xz

BuildRequires: boost-devel
#BuildRequires: cmake
BuildRequires: libxml2-utils
BuildRequires: libxml2-devel
BuildRequires: pkgconfig(cunit)
BuildRequires: pkgconfig(libev)
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(libcares)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(jansson)
BuildRequires: pkgconfig(libevent)
BuildRequires: pkgconfig(jemalloc)
%if %with_docs
# Used to build the documentation
BuildRequires: python3dist(sphinx)
BuildRequires: python-sphinx-locales
BuildRequires: python3dist(sphinxcontrib-rubydomain)
%endif

%description
This package contains the HTTP/2 client, server and proxy programs.

%package -n %{libname}
Summary: A library implementing the HTTP/2 protocol
Group: System/Libraries
Provides: libnghttp2 = %{version}-%{release}

%description -n %{libname}
libnghttp2 is a library implementing the Hypertext Transfer Protocol
version 2 (HTTP/2) protocol in C.

%package -n %{develname}
Summary: Files needed for building applications with libnghttp2
Group: Development/C
Provides: %{name}-devel = %{version}-%{release}
Requires: %{libname} >= %{version}-%{release}

%description -n %{develname}
The libnghttp2-devel package includes libraries and header files needed
for building applications with libnghttp2.

%prep
%autosetup -p1

# remove bundled
rm -rf doc/_{exts,themes}/

%build
autoreconf -fi
%serverbuild

%configure \
    --disable-hpack-tools \
    --disable-python-bindings \
    --disable-static \
    --without-libxml2 \
    --disable-failmalloc

#cmake \
#	-DENABLE_STATIC=OFF \
#	-DENABLE_PYTHON_BINDINGS=OFF \
#	-DWITH_LIBXML2:BOOL=OFF \
#	-DENABLE_FAILMALLOC=OFF \
#	-DENABLE_APP=OFF

# avoid using rpath
sed -i libtool                              \
    -e 's/^runpath_var=.*/runpath_var=/'    \
    -e 's/^hardcode_libdir_flag_spec=".*"$/hardcode_libdir_flag_spec=""/'

%make_build
%if %with_docs
%make_build html
%endif

#check
# test the just built library instead of the system one, without using rpath
#export "LD_LIBRARY_PATH=%%{buildroot}%%{_libdir}:$LD_LIBRARY_PATH"
#make_build check V=1

%install
%make_install

# not needed
rm -f "%{buildroot}%{_libdir}/libnghttp2.la"

# will be installed via %%doc
rm -f "%{buildroot}%{_datadir}/doc/nghttp2/README.rst"

# python shebangs
%py3_shebang_fix %{buildroot}%{_datadir}/nghttp2/fetch-ocsp-response

%files
%if %with_docs
%doc doc/manual/html
%endif
#{_bindir}/h2load
#{_bindir}/nghttp
#{_bindir}/nghttpd
#{_bindir}/nghttpx
%{_datadir}/nghttp2
%{_mandir}/man1/h2load.1*
%{_mandir}/man1/nghttp.1*
%{_mandir}/man1/nghttpd.1*
%{_mandir}/man1/nghttpx.1*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}
%license COPYING

%files -n %{develname}
%{_includedir}/nghttp2
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%doc README.rst


%changelog
* Mon Oct 21 2024 kekepower <kekepower> 1.64.0-1.mga10
+ Revision: 2109224
- Update to version 1.64.0

* Tue Aug 27 2024 kekepower <kekepower> 1.63.0-1.mga10
+ Revision: 2091834
- Update to version 1.63.0

* Tue May 21 2024 kekepower <kekepower> 1.62.1-1.mga10
+ Revision: 2065813
- Update to version 1.62.1

* Fri Apr 05 2024 kekepower <kekepower> 1.61.0-1.mga10
+ Revision: 2054529
- Update to version 1.61.0

* Fri Mar 01 2024 kekepower <kekepower> 1.60.0-1.mga10
+ Revision: 2046329
- Update to version 1.60.0
- Update to version 1.59.0

* Fri Oct 27 2023 kekepower <kekepower> 1.58.0-1.mga10
+ Revision: 2002141
- Update to version 1.58.0

* Tue Oct 10 2023 kekepower <kekepower> 1.57.0-1.mga10
+ Revision: 1994174
- Update to version 1.57.0

* Tue Sep 05 2023 kekepower <kekepower> 1.56.0-1.mga10
+ Revision: 1984394
- Update to version 1.56.0

* Wed Jun 07 2023 kekepower <kekepower> 1.54.0-1.mga9
+ Revision: 1961228
- Update to version 1.54.0

* Wed May 10 2023 kekepower <kekepower> 1.53.0-1.mga9
+ Revision: 1956503
- Update to version 1.53.0

* Mon Feb 13 2023 kekepower <kekepower> 1.52.0-1.mga9
+ Revision: 1941189
- Update to version 1.52.0

* Sun Nov 13 2022 kekepower <kekepower> 1.51.0-1.mga9
+ Revision: 1906718
- Update to version 1.51.0

* Sun Sep 25 2022 kekepower <kekepower> 1.50.0-1.mga9
+ Revision: 1892265
- Update to version 1.50.0

* Tue Aug 23 2022 kekepower <kekepower> 1.49.0-1.mga9
+ Revision: 1879515
- Update to version 1.49.0

* Fri Jun 24 2022 kekepower <kekepower> 1.48.0-1.mga9
+ Revision: 1865694
- Update to version 1.48.0

* Thu Mar 24 2022 umeabot <umeabot> 1.47.0-2.mga9
+ Revision: 1825140
- Mageia 9 Mass Rebuild

* Mon Feb 28 2022 kekepower <kekepower> 1.47.0-1.mga9
+ Revision: 1786663
- Update to version 1.47.0

* Tue Oct 19 2021 kekepower <kekepower> 1.46.0-1.mga9
+ Revision: 1752192
- Update to version 1.46.0

* Sun Sep 26 2021 luigiwalser <luigiwalser> 1.45.1-1.mga9
+ Revision: 1746553
- just build library (missing deps for apps)
- remove patch
- 1.45.1

* Sun Jul 18 2021 kekepower <kekepower> 1.44.0-1.mga9
+ Revision: 1736553
- Update to version 1.44.0

* Fri Mar 05 2021 kekepower <kekepower> 1.43.0-1.mga9
+ Revision: 1699637
- Update to version 1.43.0

* Sat Nov 28 2020 kekepower <kekepower> 1.42.0-1.mga8
+ Revision: 1650005
- Update to version 1.42.0

* Wed Jun 03 2020 kekepower <kekepower> 1.41.0-1.mga8
+ Revision: 1590126
- Update to version 1.41.0

* Fri Apr 17 2020 kekepower <kekepower> 1.40.0-3.mga8
+ Revision: 1568307
- Disable building the documentation for now

* Tue Feb 18 2020 daviddavid <daviddavid> 1.40.0-2.mga8
+ Revision: 1539585
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Dec 08 2019 kekepower <kekepower> 1.40.0-1.mga8
+ Revision: 1465240
- Update to version 1.40.0

* Sat Aug 17 2019 wally <wally> 1.39.2-3.mga8
+ Revision: 1429551
- build with libxml2 and sphinxcontrib-rubydomain

* Sat Aug 17 2019 kekepower <kekepower> 1.39.2-2.mga8
+ Revision: 1429544
- Update to version 1.39.2
- Add patch to remove sphinxcontrib.rubydomain extension
+ wally <wally>
- switch to python3-sphinx for doc build

* Mon Apr 22 2019 kekepower <kekepower> 1.38.0-1.mga7
+ Revision: 1394628
- Update to version 1.38.0

* Sat Mar 30 2019 luigiwalser <luigiwalser> 1.37.0-1.mga7
+ Revision: 1382064
- 1.37.0

* Mon Jan 21 2019 luigiwalser <luigiwalser> 1.36.0-1.mga7
+ Revision: 1358574
- 1.36.0

* Sun Dec 30 2018 luigiwalser <luigiwalser> 1.35.1-1.mga7
+ Revision: 1346819
- 1.35.1

* Mon Dec 03 2018 tmb <tmb> 1.35.0-1.mga7
+ Revision: 1338071
- update to 1.35.0

* Sat Nov 10 2018 joequant <joequant> 1.34.0-1.mga7
+ Revision: 1329293
- upgrade to 1.34

* Sun Sep 23 2018 umeabot <umeabot> 1.32.0-2.mga7
+ Revision: 1299739
- Mageia 7 Mass Rebuild

* Sat May 19 2018 daviddavid <daviddavid> 1.32.0-1.mga7
+ Revision: 1230417
- new version: 1.32.0

* Wed Apr 18 2018 kekepower <kekepower> 1.31.1-1.mga7
+ Revision: 1219981
- Update to version 1.31.1
- Fixes CVE-2018-1000168 (mga#22906)
- Disable tests for now

* Fri Sep 08 2017 guillomovitch <guillomovitch> 1.25.0-1.mga7
+ Revision: 1151934
- new version 1.25.0

* Sun Apr 10 2016 pterjan <pterjan> 1.9.2-1.mga6
+ Revision: 999957
- Update to 1.9.2

* Wed Mar 02 2016 umeabot <umeabot> 1.8.0-2.mga6
+ Revision: 983800
- Rebuild for openssl

* Wed Mar 02 2016 oden <oden> 1.8.0-1.mga6
+ Revision: 983104
- 1.8.0

* Wed Feb 24 2016 oden <oden> 1.7.1-1.mga6
+ Revision: 978525
- 1.7.1 (fixes CVE-2016-1544)
- sync a bit with fedora

* Sun Dec 27 2015 oden <oden> 1.6.0-1.mga6
+ Revision: 915713
- 1.6.0

* Thu Nov 05 2015 oden <oden> 1.4.0-1.mga6
+ Revision: 897929
- fix some small issues...
- imported package nghttp2

